SystemOrganization addCategory: #ScriptBook!

SMPackageRelease subclass: #SBScript
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ScriptBook'!

!SBScript methodsFor: 'as yet unclassified' stamp: 'chc 4/22/2019 15:09'!
fullDescription
	"Return a full textual description of the package release."

	| s |
	s := TextStream on: (Text new: 400).
"	self describe: self package name withBoldLabel: 'Package Name: ' on: s."
	name isEmptyOrNil ifFalse:
		[self describe: self name withBoldLabel: 'Release Name: ' on: s].
	summary isEmptyOrNil ifFalse:
		[self describe: self summary withBoldLabel: 'Release Summary: ' on: s].

"	self 
		describe: self version
		withBoldLabel: 'Version: '
		on: s."

	self note isEmptyOrNil 
		ifFalse: 
			[ s withAttribute: (TextIndent tabs: 1) do: [s nextPutAll: self note withSqueakLineEndings].
			s cr].

	categories isEmptyOrNil 
		ifFalse: 
			[s
				cr;
				withAttribute: TextEmphasis bold do: [s nextPutAll: 'Categories: '];
				cr.
			(self categories sorted: [:a :b | a path < b path])
				do: [:c | 
					s
						tab;
						withAttribute: TextEmphasis italic
							do: 
								[c parentsDo: 
										[:p | 
										s
											nextPutAll: p name;
											nextPutAll: '/'].
								s nextPutAll: c name];
						nextPutAll: ' - ' , c summary;
						cr].
			s cr].

	"created ifNotNil: [
		s
			withAttribute: TextEmphasis bold do: [ s nextPutAll: 'Created: ' ];
			print: self created;
			cr].
	updated ifNotNil: [
		s
			withAttribute: TextEmphasis bold do: [ s nextPutAll: 'Modified: ' ];
			print: self updated;
			cr]."
	publisher ifNotNil: [
		s
			withAttribute: TextEmphasis bold
			do: [s nextPutAll: 'Publisher: '].
		s
			withAttribute: (PluggableTextAttribute
					evalBlock: [self userInterface
									sendMailTo: self publisher email
									regardingPackageRelease: self])
			do: [s nextPutAll: self publisher nameAndEmail];	
			cr].

	url isEmptyOrNil 
		ifFalse: 
			[s
				withAttribute: TextEmphasis bold do: [s nextPutAll: 'Homepage:'];
				tab;
				withAttribute: (TextURL new url: url) do: [s nextPutAll: url];
				cr].
	self downloadUrl isEmptyOrNil 
		ifFalse: 
			[s
				withAttribute: TextEmphasis bold do: [s nextPutAll: 'Download:'];
				tab;
					withAttribute: (TextDoIt new evalString: self downloadUrl)
					do: [s nextPutAll: self downloadUrl];

				cr].
	^s contents.

! !

SMSqueakMap subclass: #SBModel
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ScriptBook'!

!SBModel class methodsFor: 'as yet unclassified' stamp: 'chc 4/18/2019 11:21'!
new
	"Answer a new initialized instance of the receiver (which is a class) with no indexable variables. Fail if the class is indexable."

	^ self basicNew initialize
! !

!SBModel methodsFor: 'as yet unclassified' stamp: 'chc 4/16/2019 08:40'!
objects
	^objects! !

!SBModel methodsFor: 'as yet unclassified' stamp: 'chc 4/16/2019 08:40'!
objects: anObject
	objects := anObject! !

SMLoaderPlus subclass: #ScriptBook
	instanceVariableNames: 'scripts'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ScriptBook'!

!ScriptBook commentStamp: 'chc 9/26/2019 12:47' prior: 0!
I save scripts strings to a method storing in a code repository like SqueakSource

ScriptBook open

scripts - a Dictionary of scripts strings and their names!

!ScriptBook methodsFor: 'button commands' stamp: 'chc 9/16/2019 12:28'!
addNewScript: aName
	|package release |
	package := SMPackage newIn: map. 
	package name: aName.
	release := SBScript newFromRelease: nil package: package. 
	release downloadUrl: ''.	
	package addRelease: release. 
	Model addObject: package.
	"packages := nil"
	self changed: #packageList
	! !

!ScriptBook methodsFor: 'build tool' stamp: 'chc 9/12/2019 12:54'!
buildPackagePaneWith: aBuilder
	"Create the text area to the right in the loader."

	^ aBuilder pluggableTextSpec new
		model: self;
		getText: #itemDescription;
		setText: #saveScriptToModel:;
		name: #packagePane;
		help: 'Paste script into this window and press Save.';
		yourself! !

!ScriptBook methodsFor: 'build tool' stamp: 'chc 5/7/2019 11:45'!
buildWith: aBuilder 
	"Create the package loader window."
	| buttonBarHeight searchPaneHeight vertDivide horizDivide |
	buttonBarHeight := Preferences standardButtonFont height * 2.
	searchPaneHeight := Preferences standardDefaultTextFont height * 2.
	vertDivide := 0.6.
	horizDivide := 0.3.
	builder := aBuilder.
	window := builder build: (builder pluggableWindowSpec new model: self;
					 label: #label;
					 children: (OrderedCollection new
						add: ((self buildButtonBarWith: builder)
							frame: (LayoutFrame
								fractions: (0 @ 0 corner: 1 @ 0)
								offsets: (0@0 corner: 0@buttonBarHeight)));
						add: ((self buildPackagesListWith: builder)
							frame: (LayoutFrame
								fractions: (0 @ 0 corner: horizDivide @ 1)
								offsets: (0 @ (buttonBarHeight) corner: 0@0)));
						add: ((self buildPackagePaneWith: builder)
								frame: (LayoutFrame
									fractions: (horizDivide @ 0 corner: 1 @ 1)
									offsets: (0 @ buttonBarHeight corner: 0@0)));
						 yourself);
					 yourself).
	window on: #mouseEnter send: #paneTransition: to: window.
	window on: #mouseLeave send: #paneTransition: to: window.
	window extent: self initialExtent.
	^ window! !

!ScriptBook methodsFor: 'build tool' stamp: 'chc 10/2/2019 09:59'!
commandSpecs
	^ #(('New' getNewScriptName 'Click to add a new script' (all))
		('Remove' removeScript 'Remove a script from the book' (all))
		('Transcript' printToTranscript 'Show all scripts in a Transcript window.' (all))
		"('Save' browseCacheDirectory 'Save new scripts in #myscripts method as a string.' (all))
		('Load' openReleaseEditor 'Load scripts from #myscripts.' (all))
		('Create new Release' createNewRelease 'Create a new release based on the selected item' (item))
		('Force download into cache' downloadPackageRelease 'Force a download of the selected release into the cache.' (item))
		('Update' loadUpdates 'Update the package index from the servers.' (all))
		('Upgrade All' upgradeInstalledPackagesConfirm 'Upgrade all installed packages (confirming each).' (all))
		('Upgrade all installed packages' upgradeInstalledPackagesNoConfirm '' (item))
		('Upgrade all installed packages confirming each' upgradeInstalledPackagesConfirm '' (item))
		('Copy list' listInPasteBuffer 'Puts the list as text into the clipboard.' (all))
		('Save filters' saveFiltersAsDefault 'Saves the current filters as default.' (all))
		('Help' help 'What is this?' (all))")! !

!ScriptBook methodsFor: 'build tool' stamp: 'chc 4/15/2019 09:36'!
defaultLabel
	^ 'Script Book'! !

!ScriptBook methodsFor: 'as yet unclassified' stamp: 'chc 6/14/2019 13:39'!
getNewScriptName
	"put a Morph pop up to collect a script name; then feed it to addNewScript:"
	| newScriptName |
	newScriptName := FillInTheBlank request: 'Name your script:' translated initialAnswer: ''.
	self addNewScript: newScriptName! !

!ScriptBook methodsFor: 'as yet unclassified' stamp: 'chc 9/30/2019 11:53'!
initialize
	map := SBModel new.
	map objects: Dictionary new. 
	self scripts: (Compiler evaluate: self scriptsData).
	self scripts keysAndValuesDo: [:key :value| 
		self storeString: key toModel: value ].
	(Smalltalk at: #ToolBuilder) open: self 
	! !

!ScriptBook methodsFor: 'as yet unclassified' stamp: 'chc 7/8/2019 18:39'!
model
	^Model! !

!ScriptBook methodsFor: 'storage string' stamp: 'chc 9/30/2019 11:58'!
model: aScript toStoreString: aName
	"take the SMModel and collect the scripts into a the scripts ivar Dictionary and then produce a storeString to sae in the scriptsData method"
	|package release |
	package := SMPackage newIn: map. 
	package name: aName.
	release := SBScript newFromRelease: nil package: package. 
	release downloadUrl: aScript.	
	package addRelease: release. 
	map addObject: package.
! !

!ScriptBook methodsFor: 'as yet unclassified' stamp: 'chc 4/15/2019 09:53'!
packageList
	| list |
	list := map packages.
	^ list! !

!ScriptBook methodsFor: 'button commands' stamp: 'chc 10/2/2019 10:01'!
printToTranscript
	"print all the scripts to a Transcript"
	|tr|
	tr := Transcript open.
	scripts keysAndValuesDo: [:key :value| 
						tr cr; cr. 
						tr show: 'SCRIPT NAME: ' ,  value.
						tr cr; cr. 
						tr show: key ]! !

!ScriptBook methodsFor: 'button commands' stamp: 'chc 9/4/2019 11:57'!
removeScript
	map objects removeKey: (map packageWithName: (selectedItem name)) id ifAbsent: [].
	self map clearCaches. 
	self changed: #packageList! !

!ScriptBook methodsFor: 'as yet unclassified' stamp: 'chc 9/12/2019 13:02'!
saveScriptToModel: aText
	selectedItem downloadUrl: aText string
	
! !

!ScriptBook methodsFor: 'accessing' stamp: 'chc 9/26/2019 12:42'!
scripts

	^ scripts! !

!ScriptBook methodsFor: 'accessing' stamp: 'chc 9/26/2019 12:42'!
scripts: anObject

	scripts := anObject.! !

!ScriptBook methodsFor: 'storage string' stamp: 'chc 9/30/2019 11:56'!
scriptsData
	^'((Dictionary new) add: (''(Installer ss project: ''''CommandShell'''') install: ''''CommandShell-dtl.96''''''->''Command Shell''); add: (''Installer ensureGitInfrastructure''->''Git''); add: (''(FileDirectory default  directoryExists: ''''ScratchSkin'''') ifFalse:[ UIManager default inform: ''''Before loading this package you must download\ http://download.scratch.mit.edu/source-code/ScratchSkin1.4.zip\ and unzip it to create the ScratchSkin directory\ with all the required media files.'''' withCRs.
	^0].
(Installer repository: ''''http://www.squeaksource.com/NuScratch'''' ) install: ''''NuScratch-tpr.381.mcz''''''->''NuScratch''); add: (''"Turn classes into files"
	Installer ensureRecentMetacello.
(Smalltalk classNamed: #Metacello) new
   repository: ''''github://j4yk/tonel:squeak'''';
   baseline: ''''Tonel'''';
   load''->''Tonel''); add: (''Installer ss
 	project: ''''Xtreams'''';
 	addPackage: ''''Xtreams-Support'''';
 	addPackage: ''''Xtreams-Core'''';
 	addPackage: ''''Xtreams-Terminals'''';
 	addPackage: ''''Xtreams-TerminalsFileDirectory'''';
 	addPackage: ''''Xtreams-Transforms'''';
 	addPackage: ''''Xtreams-Substreams'''';
 	addPackage: ''''Xtreams-Parsing'''';
 	install.''->''Xtreams''); add: (''"Provides source code completion as you type"
(Installer ss project: ''''OCompletion'''')
      addPackage: ''''OcompletionSqueakCompatibility'''';
	addPackage: ''''Ocompletion'''';
	install.
(Smalltalk at: #ECToolSet) register.
(Smalltalk at: #ToolSet) default: (Smalltalk at: #ECToolSet)''->''OCompletion''); add: (''Installer ensureRecentMetacello''->''Metacello''); add: (''Installer ensureRecentMetacello.
Metacello new
	configuration: ''''RefactoringTools'''';
	load.''->''Refactoring Tools''); add: (''Installer ensureRecentMetacello.

(Smalltalk at: #Metacello) new
 baseline:''''Seaside3'''';
 repository: ''''github://SeasideSt/Seaside:master/repository'''';
 load.

(Installer ss3 project: ''''WebClient'''')
        install: ''''WebClient-Seaside-Adaptor''''.

"Optionally use the control panel to add adaptor, start and to set encoding"
"WAControlPanel open."

"do the above but without using the GUI"
((Smalltalk at: #WAWebServerAdaptor) port: 8080)
        codec: ((Smalltalk at: #GRCodec) forEncoding: ''''utf-8'''');
        start.''->''Seaside3''); add: (''Installer ensureRecentMetacello.

Metacello new
    repository: ''''github://theseion/Fuel:3.0.0/repository'''';
    baseline: ''''Fuel'''';
    load.''->''Fuel''); add: (''(Installer ss project: ''''OSProcess'''') install: ''''OSProcess-dtl.110''''''->''OSProcess''); add: (''#( ''''JSON-tonyg.39.mcz'''' ) do:
	[:each| (Installer repository: ''''http://www.squeaksource.com/JSON'''') install: each]''->''JSON''); yourself)'! !

!ScriptBook methodsFor: 'storage string' stamp: 'chc 9/30/2019 11:57'!
storeString: aScript toModel: aName
	"populate the scripts ivar with the Dictionary from the scriptsData method and then populate the SMModel"
	|package release |
	package := SMPackage newIn: map. 
	package name: aName.
	release := SBScript newFromRelease: nil package: package. 
	release downloadUrl: aScript.	
	package addRelease: release. 
	map addObject: package.
! !
